"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 213df39bd5e6

from __future__ import annotations
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FunctionResultEntryTypedDict(TypedDict):
    tool_call_id: str
    result: str
    object: Literal["entry"]
    type: Literal["function.result"]
    created_at: NotRequired[datetime]
    completed_at: NotRequired[Nullable[datetime]]
    id: NotRequired[str]


class FunctionResultEntry(BaseModel):
    tool_call_id: str

    result: str

    object: Annotated[
        Annotated[Optional[Literal["entry"]], AfterValidator(validate_const("entry"))],
        pydantic.Field(alias="object"),
    ] = "entry"

    type: Annotated[
        Annotated[
            Optional[Literal["function.result"]],
            AfterValidator(validate_const("function.result")),
        ],
        pydantic.Field(alias="type"),
    ] = "function.result"

    created_at: Optional[datetime] = None

    completed_at: OptionalNullable[datetime] = UNSET

    id: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["object", "type", "created_at", "completed_at", "id"])
        nullable_fields = set(["completed_at"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m


try:
    FunctionResultEntry.model_rebuild()
except NameError:
    pass
