"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 99d94c86a871

from __future__ import annotations
from .batchjob import BatchJob, BatchJobTypedDict
from mistralai.client.types import BaseModel, UNSET_SENTINEL
from mistralai.client.utils import validate_const
import pydantic
from pydantic import model_serializer
from pydantic.functional_validators import AfterValidator
from typing import List, Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListBatchJobsResponseTypedDict(TypedDict):
    total: int
    data: NotRequired[List[BatchJobTypedDict]]
    object: Literal["list"]


class ListBatchJobsResponse(BaseModel):
    total: int

    data: Optional[List[BatchJob]] = None

    object: Annotated[
        Annotated[Optional[Literal["list"]], AfterValidator(validate_const("list"))],
        pydantic.Field(alias="object"),
    ] = "list"

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["data", "object"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ListBatchJobsResponse.model_rebuild()
except NameError:
    pass
