"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ee708a7ccdad

from __future__ import annotations
from .sharingout import SharingOut, SharingOutTypedDict
from mistralai.client.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListSharingOutTypedDict(TypedDict):
    data: List[SharingOutTypedDict]


class ListSharingOut(BaseModel):
    data: List[SharingOut]
